@@ -38,6 +38,8 @@ class xt(ArchiveUnit):
         yield xttar
         from refinery.units.formats.office.xtdoc import xtdoc
         yield xtdoc
+        from refinery.units.formats.archive.xtiss import xtiss
+        yield xtiss
         from refinery.units.formats.exe.vsect import vsect
         yield vsect
 
@@ -51,10 +53,11 @@ class xt(ArchiveUnit):
             date=self.args.date,
             join_path=self.args.join,
             drop_path=self.args.drop,
-            regex=self.args.regex
         )
         if self.args.pwd:
             key_args.update(pwd=self.args.pwd)
+        if self.args.regex:
+            key_args.update(regex=self.args.regex)
 
         class unpacker:
             unit = self
