@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from refinery.units.formats import arg, PathExtractorUnit, UnpackResult
+from refinery.units.formats import Arg, PathExtractorUnit, UnpackResult
 from refinery.units import RefineryPartialResult
 from refinery.lib.tools import isbuffer
 from refinery.lib.dotnet.resources import NetStructuredResources, NoManagedResource
@@ -12,7 +12,7 @@ class dnmr(PathExtractorUnit):
     """
     def __init__(
         self, *paths, list=False, join_path=False, drop_path=False, path=b'name',
-        raw: arg.switch('-r', help='Do not deserialize the managed resource entry data.') = False
+        raw: Arg.Switch('-r', help='Do not deserialize the managed resource entry data.') = False
     ):
         super().__init__(*paths, list=list, join_path=join_path, drop_path=drop_path, path=path, raw=raw)
 
