@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from ... import PathExtractorUnit, UnpackResult
-from .....lib.dotnet.header import DotNetHeader
+from refinery.units.formats import PathExtractorUnit, UnpackResult
+from refinery.lib.dotnet.header import DotNetHeader
 
 
 class dnrc(PathExtractorUnit):
